"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;
var _helpers = require("./helpers");
var propsNames = new Set();
var flags = new Map();
var imports = new Map();
var beforeSetupStatement = new Map(null);
var afterSetupStatement = new Map(null);
var setupContextKeys = new Set();
var refsName = new Set();
var excludeRefsName = new Set();
var returnStatement = new Map(null);
var props = new Map(null);
var plugins = new Map();
var ConversionStore = function () {
  var addRef = function addRef(name) {
    refsName.add(name);
  };
  var addExcludeRef = function addExcludeRef(name) {
    excludeRefsName.add(name);
  };
  var hasExcludeRefsName = function hasExcludeRefsName(name) {
    return excludeRefsName.has(name);
  };
  var hasRefName = function hasRefName(name) {
    return refsName.has(name);
  };
  var addReturnStatement = function addReturnStatement(name, node) {
    returnStatement.set(name, node);
  };
  var addShortReturnStatementByName = function addShortReturnStatementByName(name) {
    returnStatement.set(name, (0, _helpers.createShortHandProperty)(name));
  };
  var getReturnStatement = function getReturnStatement() {
    return returnStatement;
  };
  var addSetupContextKey = function addSetupContextKey(name) {
    setupContextKeys.add(name);
  };
  var getSetupContextKeys = function getSetupContextKeys() {
    return setupContextKeys;
  };
  var addBeforeSetupStatement = function addBeforeSetupStatement(name, node) {
    beforeSetupStatement.set(name, node);
  };
  var getBeforeSetupStatements = function getBeforeSetupStatements() {
    return beforeSetupStatement;
  };
  var addAfterSetupStatement = function addAfterSetupStatement(name, node) {
    afterSetupStatement.set(name, node);
  };
  var getAfterSetupStatements = function getAfterSetupStatements() {
    return afterSetupStatement;
  };
  var addImport = function addImport(source, key) {
    var isDefault = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : false;
    if (imports.has(source)) {
      var current = imports.get(source);
      current.set(key, {
        value: key,
        isDefault: isDefault
      });
    } else {
      imports.set(source, new Map([[key, {
        value: key,
        isDefault: isDefault
      }]]));
    }
  };
  var getImports = function getImports() {
    return imports;
  };
  var addProp = function addProp(propName, node) {
    props.set(propName, node);
  };
  var getProps = function getProps() {
    return props;
  };

  // Метод для добавления пропса
  var addPropName = function addPropName(propName) {
    propsNames.add(propName);
  };

  // Метод для проверки наличия пропса
  var hasPropName = function hasPropName(propName) {
    return propsNames.has(propName);
  };

  // Метод для установки флага
  var setFlag = function setFlag(flagName, value) {
    flags.set(flagName, value);
  };

  // Метод для получения значения флага
  var getFlag = function getFlag(flagName) {
    return flags.get(flagName);
  };

  // Методы для управления плагинами
  var registerPlugin = function registerPlugin(name, plugin) {
    plugins.set(name, plugin);
  };
  var getPlugins = function getPlugins() {
    return Array.from(plugins.values());
  };
  var clear = function clear() {
    imports.clear();
    propsNames.clear();
    props.clear();
    flags.clear();
    beforeSetupStatement.clear();
    afterSetupStatement.clear();
    setupContextKeys.clear();
    refsName.clear();
    excludeRefsName.clear();
    returnStatement.clear();
  };
  var printStore = function printStore() {
    console.log('Props:', Array.from(propsNames));
    console.log('Flags:', Array.from(flags.entries()));
    console.log('Imports:', Array.from(imports.entries()));
    console.log('Return:', Array.from(returnStatement.entries()));
  };
  return {
    addPropName: addPropName,
    hasPropName: hasPropName,
    setFlag: setFlag,
    getFlag: getFlag,
    clear: clear,
    printStore: printStore,
    addImport: addImport,
    getImports: getImports,
    addBeforeSetupStatement: addBeforeSetupStatement,
    getBeforeSetupStatements: getBeforeSetupStatements,
    addSetupContextKey: addSetupContextKey,
    getSetupContextKeys: getSetupContextKeys,
    addAfterSetupStatement: addAfterSetupStatement,
    getAfterSetupStatements: getAfterSetupStatements,
    addReturnStatement: addReturnStatement,
    getReturnStatement: getReturnStatement,
    addRef: addRef,
    hasRefName: hasRefName,
    addShortReturnStatementByName: addShortReturnStatementByName,
    addExcludeRef: addExcludeRef,
    hasExcludeRefsName: hasExcludeRefsName,
    registerPlugin: registerPlugin,
    getPlugins: getPlugins,
    addProp: addProp,
    getProps: getProps
  };
}();
var _default = exports["default"] = ConversionStore;